@@ -2,34 +2,16 @@ import numpy as np
 import pandas as pd
 
 from .complexity_hjorth import complexity_hjorth
-from .complexity_lempelziv import complexity_lempelziv
-from .complexity_lyapunov import complexity_lyapunov
-from .complexity_relativeroughness import complexity_relativeroughness
-from .entropy_approximate import entropy_approximate
-from .entropy_cumulativeresidual import entropy_cumulativeresidual
-from .entropy_differential import entropy_differential
-from .entropy_fuzzy import entropy_fuzzy
+from .entropy_attention import entropy_attention
+from .entropy_bubble import entropy_bubble
 from .entropy_multiscale import entropy_multiscale
 from .entropy_permutation import entropy_permutation
-from .entropy_range import entropy_range
-from .entropy_sample import entropy_sample
-from .entropy_shannon import entropy_shannon
-from .entropy_spectral import entropy_spectral
 from .entropy_svd import entropy_svd
-from .fractal_correlation import fractal_correlation
 from .fractal_dfa import fractal_dfa
-from .fractal_higuchi import fractal_higuchi
-from .fractal_hurst import fractal_hurst
-from .fractal_katz import fractal_katz
-from .fractal_nld import fractal_nld
-from .fractal_petrosian import fractal_petrosian
-from .fractal_psdslope import fractal_psdslope
-from .fractal_sda import fractal_sda
-from .fractal_sevcik import fractal_sevcik
-from .information_fisher import fisher_information
+from .fractal_linelength import fractal_linelength
 
 
-def complexity(signal, which=["fast", "medium"], delay=1, dimension=2, tolerance="sd", **kwargs):
+def complexity(signal, which="makowski2022", delay=1, dimension=2, tolerance="sd", **kwargs):
     """**Complexity and Chaos Analysis**
 
     Measuring the complexity of a signal refers to the quantification of various aspects related to
@@ -37,15 +19,15 @@ def complexity(signal, which=["fast", "medium"], delay=1, dimension=2, tolerance
 
     .. tip::
 
-        We recommend checking our open-access `preprint <https://psyarxiv.com/f8k3x/>`_ for an
+        We recommend checking our open-access `review <https://onlinelibrary.wiley.com/doi/10.1111/ejn.15800>`_ for an
         introduction to **fractal physiology** and its application in neuroscience.
 
-    There are many indices that have been developped and used to assess the complexity of signals,
+    There are many indices that have been developed and used to assess the complexity of signals,
     and all of them come with different specificities and limitations. While they should be used in
     an informed manner, it is also convenient to have a single function that can compute multiple
     indices at once.
 
-    The ``nk.complexity()`` function can be used to compute a large number of complexity metrics
+    The ``nk.complexity()`` function can be used to compute a useful subset of complexity metrics
     and features. While this is great for exploratory analyses, we recommend running each function
     separately, to gain more control over the parameters and information that you get.
 
@@ -55,20 +37,22 @@ def complexity(signal, which=["fast", "medium"], delay=1, dimension=2, tolerance
         depending on what the literature suggests. We recommend using this function only for quick
         exploratory analyses, but then replacing it by the calls to the individual functions.
 
-    The categorization by "computation time" is based on our preliminary `benchmarking study
-    <https://neuropsychology.github.io/NeuroKit/studies/complexity_benchmark.html>`_ results:
+        Check-out our open-access `study <https://onlinelibrary.wiley.com/doi/10.1111/ejn.15800>`_
+        explaining the selection of indices.
 
-    .. figure:: ../../studies/complexity_benchmark/figures/computation_time-1.png
+    The categorization by "computation time" is based on our `study
+    <https://www.mdpi.com/1099-4300/24/8/1036>`_ results:
+
+    .. figure:: https://raw.githubusercontent.com/DominiqueMakowski/ComplexityStructure/main/figures/time1-1.png
        :alt: Complexity Benchmark (Makowski).
-       :target: https://neuropsychology.github.io/NeuroKit/studies/complexity_benchmark.html
+       :target: https://www.mdpi.com/1099-4300/24/8/1036
 
     Parameters
     ----------
     signal : Union[list, np.array, pd.Series]
         The signal (i.e., a time series) in the form of a vector of values.
     which : list
-        What metrics to compute, based on their computation time. Can be ``"fast"``, ``"medium"``,
-        or ``"slow"``.
+        What metrics to compute. Can be "makowski2022".
     delay : int
         Time delay (often denoted *Tau* :math:`\\tau`, sometimes referred to as *lag*) in samples.
         See :func:`complexity_delay` to estimate the optimal value for this parameter.
@@ -102,19 +86,11 @@ def complexity(signal, which=["fast", "medium"], delay=1, dimension=2, tolerance
       # Simulate a signal of 3 seconds
       signal = nk.signal_simulate(duration=3, frequency=[5, 10])
 
-      # Fast metrics
-      df, info = nk.complexity(signal, which = ["fast", "medium"])
+      # Compute selection of complexity metrics (Makowski et al., 2022)
+      df, info = nk.complexity(signal, which = "makowski2022")
       df
 
-    * **Example 2**: Compute slow complexity metrics
-
-    .. ipython:: python
-
-      # Slow, with specific parameters for Higuchi and MFDFA
-      df, info = nk.complexity(signal, which = "slow", k_max=6, q=range(-2, 3))
-      df
-
-    * **Example 3**: Compute complexity over time
+    * **Example 2**: Compute complexity over time
 
     .. ipython:: python
 
@@ -170,6 +146,15 @@ def complexity(signal, which=["fast", "medium"], delay=1, dimension=2, tolerance
       @suppress
       plt.close()
 
+    References
+    ----------
+    * Lau, Z. J., Pham, T., Chen, S. H. A., & Makowski, D. (2022). Brain entropy, fractal
+      dimensions and predictability: A review of complexity measures for EEG in healthy and
+      neuropsychiatric populations. European Journal of Neuroscience, 1-23.
+    * Makowski, D., Te, A. S., Pham, T., Lau, Z. J., & Chen, S. H. (2022). The Structure of Chaos:
+      An Empirical Comparison of Fractal Physiology Complexity Indices Using NeuroKit2. Entropy, 24
+      (8), 1036.
+
     """
     # Sanity checks
     if isinstance(signal, (np.ndarray, pd.DataFrame)) and signal.ndim > 1:
@@ -177,92 +162,33 @@ def complexity(signal, which=["fast", "medium"], delay=1, dimension=2, tolerance
             "Multidimensional inputs (e.g., matrices or multichannel data) are not supported yet."
         )
 
-    # Sanitize which
-    if isinstance(which, str):
-        which = [which]
-
     # Initialize
     df = {}
     info = {}
 
     # Fast ======================================================================================
-    if "fast" in which:
+    if which in ["makowski2022", "makowski"]:
 
-        # Fractal Dimension
-        df["PFD"], info["PFD"] = fractal_petrosian(signal)
-        df["KFD"], info["KFD"] = fractal_katz(signal)
-        df["SFD"], info["SFD"] = fractal_sevcik(signal)
-
-        # Entropy
-        df["DiffEn"], info["DiffEn"] = entropy_differential(signal)
-        df["PEn"], info["PEn"] = entropy_permutation(signal, dimension=dimension, delay=delay)
-        df["ShanEn"], info["ShanEn"] = entropy_shannon(signal)
-        df["SpEn"], info["SpEn"] = entropy_spectral(signal)
-        df["SVDEn"], info["SVDEn"] = entropy_svd(signal, delay=delay, dimension=dimension)
-
-        # Other
-        df["FI"], info["FI"] = fisher_information(signal, delay=delay, dimension=dimension)
+        df["LL"], info["LL"] = fractal_linelength(signal)
         df["Hjorth"], info["Hjorth"] = complexity_hjorth(signal)
-        df["RR"], info["RR"] = complexity_relativeroughness(signal)
-
-    if "medium" in which:
-
-        # Fractal Dimension
-        df["NLD"], info["NLD"] = fractal_nld(signal, corrected=False)
-        df["SDA"], info["SDA"] = fractal_sda(signal)
-        df["PSDslope"], info["PSDslope"] = fractal_psdslope(signal)
-
-        # Entropy
-        df["CREn"], info["CREn"] = entropy_cumulativeresidual(signal)
-        df["ApEn"], info["ApEn"] = entropy_approximate(
-            signal, delay=delay, dimension=dimension, tolerance=tolerance
+        df["AttEn"], info["AttEn"] = entropy_attention(signal)
+        df["SVDEn"], info["SVDEn"] = entropy_svd(signal, delay=delay, dimension=dimension)
+        df["BubbEn"], info["BubbEn"] = entropy_bubble(
+            signal, delay=delay, dimension=dimension, **kwargs
         )
-        df["SampEn"], info["SampEn"] = entropy_sample(
-            signal, dimension=dimension, delay=delay, tolerance=tolerance
+        df["CWPEn"], info["CWPEn"] = entropy_permutation(
+            signal,
+            delay=delay,
+            dimension=dimension,
+            corrected=True,
+            weighted=True,
+            conditional=True,
+            **kwargs
         )
-        df["MSEn"], info["MSEn"] = entropy_multiscale(
-            signal, dimension=dimension, tolerance=tolerance, method="MSEn"
-        )
-        df["MSPEn"], info["MSPEn"] = entropy_permutation(
-            signal, dimension=dimension, delay=delay, scale="default"
-        )
-        df["WPEn"], info["WPEn"] = entropy_permutation(
-            signal, dimension=dimension, delay=delay, weighted=True
+        df["MSPEn"], info["MSPEn"] = entropy_multiscale(
+            signal, dimension=dimension, method="MSPEn", **kwargs
         )
 
-        # Other
-        df["Hurst"], info["Hurst"] = fractal_hurst(signal)
-        df["LZC"], info["LZC"] = complexity_lempelziv(signal, dimension=dimension, delay=delay)
-        df["PLZC"], info["PLZC"] = complexity_lempelziv(
-            signal, dimension=dimension, delay=delay, permutation=True
-        )
-
-    if "slow" in which:
-
-        # Fractal Dimension
-        df["CD"], info["CD"] = fractal_correlation(signal, delay=delay, dimension=dimension)
-        df["HFD"], info["HFD"] = fractal_higuchi(signal, **kwargs)
-
-        # Entropy
-        df["FuzzyEn"], info["FuzzyEn"] = entropy_fuzzy(
-            signal, dimension=dimension, delay=delay, tolerance=tolerance
-        )
-        df["RCMSEn"], info["RCMSEn"] = entropy_multiscale(
-            signal, dimension=dimension, tolerance=tolerance, method="RCMSEn"
-        )
-        df["FuzzyMSEn"], info["FuzzyMSEn"] = entropy_multiscale(
-            signal, dimension=dimension, tolerance=tolerance, fuzzy=True
-        )
-        df["FuzzyRCMSEn"], info["FuzzyRCMSEn"] = entropy_multiscale(
-            signal, dimension=dimension, tolerance=tolerance, method="RCMSEn", fuzzy=True
-        )
-        df["RangeEn"], info["RangeEn"] = entropy_range(
-            signal, dimension=dimension, delay=delay, tolerance=tolerance
-        )
-
-        # Other
-        df["LLE"], info["LLE"] = complexity_lyapunov(signal, dimension=dimension, delay=delay)
-        df["DFA"], info["DFA"] = fractal_dfa(signal)
         mfdfa, _ = fractal_dfa(signal, multifractal=True, **kwargs)
         for k in mfdfa.columns:
             df["MFDFA_" + k] = mfdfa[k].values[0]
