@@ -3,6 +3,7 @@
 from .data import data
 from .read_acqknowledge import read_acqknowledge
 from .read_bitalino import read_bitalino
+from .read_video import read_video
 from .write_csv import write_csv
 
-__all__ = ["read_acqknowledge", "read_bitalino", "data", "write_csv"]
+__all__ = ["read_acqknowledge", "read_bitalino", "read_video", "data", "write_csv"]
