@@ -4,10 +4,19 @@ from ..signal import signal_filter
 def ecg_rsp(ecg_rate, sampling_rate=1000, method="vangent2019"):
     """**ECG-Derived Respiration (EDR)**
 
-    Extract ECG-Derived Respiration (EDR), a proxy of a respiratory signal based on heart rate. *
-    Note that this implementation is far from being complete, as the information in the related
-    papers prevents me from getting a full understanding of the procedure. **Help is required to
-    document, test and validate the function!**
+    Extract ECG-Derived Respiration (EDR), a proxy of a respiratory signal based on heart rate.
+
+    Different methods include:
+
+    * **vangent2019**: 0.1-0.4 Hz filter.
+    * **soni2019**: 0-0.5 Hz filter.
+    * **charlton2016**: 0.066-1 Hz filter.
+    * **sarkar2015**: 0.1-0.7 Hz filter.
+
+
+    .. warning::
+
+        Help is required to double-check whether the implementation match the papers.
 
     Parameters
     ----------
@@ -40,9 +49,13 @@ def ecg_rsp(ecg_rate, sampling_rate=1000, method="vangent2019"):
 
       # Get ECG Derived Respiration (EDR) and add to the data
       data["EDR"] = nk.ecg_rsp(ecg_rate, sampling_rate=100)
+
       # Visualize result
       @savefig p_ecg_rsp1.png scale=100%
       nk.signal_plot([data["RSP"], data["EDR"]], standardize = True)
+      @suppress
+      plt.close()
+
 
     * **Example 2:** Methods comparison
 
@@ -57,6 +70,8 @@ def ecg_rsp(ecg_rate, sampling_rate=1000, method="vangent2019"):
       @savefig p_ecg_rsp2.png scale=100%
       nk.signal_plot([data["RSP"], data["vangent2019"], data["sarkar2015"],
                       data["charlton2016"], data["soni2019"]], standardize = True)
+      @suppress
+      plt.close()
 
     References
     ----------
@@ -72,25 +87,26 @@ def ecg_rsp(ecg_rate, sampling_rate=1000, method="vangent2019"):
       meditation effects. International Journal of Yoga, 12(1), 45.
 
     """
+    # TODO: It would be interesting to run a study in which we modulate the different filtering
+    # parameters and compute the difference with the real RSP signal, and then suggest the optimal
+    # filtering parameters. If you're interested in helping out let us know!
     method = method.lower()
-    if method in [
-        "sarkar2015"
-    ]:  # https://www.researchgate.net/publication/304221962_Extraction_of_respiration_signal_from_ECG_for_respiratory_rate_estimation # noqa: E501
+    if method in ["sarkar2015"]:
+        # https://www.researchgate.net/publication/304221962_Extraction_of_respiration_signal_from_ECG_for_respiratory_rate_estimation # noqa: E501
         rsp = signal_filter(ecg_rate, sampling_rate, lowcut=0.1, highcut=0.7, order=6)
-    elif method in [
-        "charlton2016"
-    ]:  # https://www.ncbi.nlm.nih.gov/pmc/articles/PMC5390977/#__ffn_sectitle
+    elif method in ["charlton2016"]:
+        # https://www.ncbi.nlm.nih.gov/pmc/articles/PMC5390977/#__ffn_sectitle
         rsp = signal_filter(ecg_rate, sampling_rate, lowcut=4 / 60, highcut=60 / 60, order=6)
-    elif method in ["soni2019"]:  # https://www.ncbi.nlm.nih.gov/pmc/articles/PMC6329220/
+    elif method in ["soni2019"]:
+        # https://www.ncbi.nlm.nih.gov/pmc/articles/PMC6329220/
         rsp = signal_filter(ecg_rate, sampling_rate, highcut=0.5, order=6)
-    elif method in [
-        "vangent2019"
-    ]:  # https://github.com/paulvangentcom/heartrate_analysis_python/blob/1597e8c0b2602829428b22d8be88420cd335e939/heartpy/analysis.py#L541 # noqa: E501
+
+    elif method in ["vangent2019"]:
+        # https://github.com/paulvangentcom/heartrate_analysis_python/blob/1597e8c0b2602829428b22d8be88420cd335e939/heartpy/analysis.py#L541 # noqa: E501
         rsp = signal_filter(ecg_rate, sampling_rate, lowcut=0.1, highcut=0.4, order=2)
     else:
         raise ValueError(
-            "NeuroKit error: ecg_rsp(): 'method' should be "
-            "one of 'sarkar2015', 'charlton2016', 'soni2019' or "
+            "`method` should be one of 'sarkar2015', 'charlton2016', 'soni2019' or "
             "'vangent2019'."
         )
 
