@@ -2,7 +2,6 @@
 
 # Aliases
 # from ..signal import signal_rate as rsp_rate
-from .rsp_rate import rsp_rate
 from .rsp_amplitude import rsp_amplitude
 from .rsp_analyze import rsp_analyze
 from .rsp_clean import rsp_clean
@@ -14,10 +13,11 @@ from .rsp_peaks import rsp_peaks
 from .rsp_phase import rsp_phase
 from .rsp_plot import rsp_plot
 from .rsp_process import rsp_process
+from .rsp_rate import rsp_rate
 from .rsp_rrv import rsp_rrv
 from .rsp_rvt import rsp_rvt
 from .rsp_simulate import rsp_simulate
-
+from .rsp_symmetry import rsp_symmetry
 
 __all__ = [
     "rsp_simulate",
@@ -35,4 +35,5 @@ __all__ = [
     "rsp_intervalrelated",
     "rsp_analyze",
     "rsp_rate",
+    "rsp_symmetry",
 ]
