@@ -6,10 +6,15 @@ from ..signal import signal_interpolate
 from .rsp_fixpeaks import _rsp_fixpeaks_retrieve
 
 
-def rsp_amplitude(rsp_cleaned, peaks, troughs=None, interpolation_method="monotone_cubic"):
+def rsp_amplitude(
+    rsp_cleaned, peaks, troughs=None, method="standard", interpolation_method="monotone_cubic"
+):
     """**Compute respiratory amplitude**
 
-    Compute respiratory amplitude given the raw respiration signal and its extrema.
+    Compute respiratory amplitude given the raw respiration signal and its extrema. The
+    **standard** method computes the amplitude as the difference between a peak and its preceding
+    trough, while the **prepost** method computes the amplitude as the average of the differences
+    of peak to its preceding and succeeding troughs (Cole, 2019).
 
     Parameters
     ----------
@@ -22,6 +27,8 @@ def rsp_amplitude(rsp_cleaned, peaks, troughs=None, interpolation_method="monoto
     troughs : list or array or DataFrame or Series or dict
         The samples at which the respiration troughs (inhalation onsets) occur. If a dict or a
         is passed, it is assumed that these containers were obtained with :func:`.rsp_findpeaks`.
+    method : str
+        The method to use to compute the amplitude. Can be ``"standard"`` or ``"prepost"``.
     interpolation_method : str
         Method used to interpolate the amplitude between peaks. See :func:`.signal_interpolate`.
         ``"monotone_cubic"`` is chosen as the default interpolation method since it ensures monotone
@@ -36,14 +43,13 @@ def rsp_amplitude(rsp_cleaned, peaks, troughs=None, interpolation_method="monoto
 
     See Also
     --------
-    rsp_clean, rsp_peaks, signal_rate, rsp_process, rsp_plot
+    rsp_clean, rsp_peaks, signal_rate, rsp_process, rsp_plot, rsp_symmetry
 
     Examples
     --------
     .. ipython:: python
 
       import neurokit2 as nk
-      import pandas as pd
 
       rsp = nk.rsp_simulate(duration=90, respiratory_rate=15)
       cleaned = nk.rsp_clean(rsp, sampling_rate=1000)
@@ -51,10 +57,23 @@ def rsp_amplitude(rsp_cleaned, peaks, troughs=None, interpolation_method="monoto
 
       amplitude = nk.rsp_amplitude(cleaned, peak_signals)
       @savefig p_rsp_amp1.png scale=100%
-      fig = nk.signal_plot(pd.DataFrame({"RSP": rsp, "Amplitude": amplitude}), subplots=True)
+      fig = nk.signal_plot([rsp, amplitude], labels=["RSP", "Amplitude"], subplots=True)
       @suppress
       plt.close()
 
+    .. ipython:: python
+
+      amp2 = nk.rsp_amplitude(cleaned, peak_signals, method="prepost")
+      @savefig p_rsp_amp2.png scale=100%
+      fig = nk.signal_plot([amplitude, amp2], labels=["Standard", "Prepost"])
+      @suppress
+      plt.close()
+
+    References
+    ----------
+    * Cole, S., & Voytek, B. (2019). Cycle-by-cycle analysis of neural oscillations. Journal of
+      neurophysiology, 122(2), 849-861.
+
     """
     # Format input.
     peaks, troughs = _rsp_fixpeaks_retrieve(peaks, troughs)
@@ -72,9 +91,21 @@ def rsp_amplitude(rsp_cleaned, peaks, troughs=None, interpolation_method="monoto
     # difference of each peak to the preceding trough.
     amplitude = rsp_cleaned[peaks] - rsp_cleaned[troughs]
 
+    # The above is the standard amplitude (each peak height to the preceding trough).
+    if method in ["prepost"]:
+        # Alternative amplitude calculation that corresponds to the average of
+        # the peak height to the preceding and following troughs.
+        # https://twitter.com/bradleyvoytek/status/1591495571269124096/photo/1
+        # (Note that it cannot be done for the last peak)
+        amplitude[0:-1] += rsp_cleaned[peaks[0:-1]] - rsp_cleaned[troughs[1::]]
+        amplitude[0:-1] /= 2
+
     # Interpolate amplitude to length of rsp_cleaned.
-    amplitude = signal_interpolate(
-        peaks, amplitude, x_new=np.arange(len(rsp_cleaned)), method=interpolation_method
-    )
+    if len(peaks) == 1:
+        amplitude = np.full(rsp_cleaned.shape, amplitude[0])
+    else:
+        amplitude = signal_interpolate(
+            peaks, amplitude, x_new=np.arange(len(rsp_cleaned)), method=interpolation_method
+        )
 
     return amplitude
