@@ -4,7 +4,7 @@ import numpy as np
 import pandas as pd
 
 
-def rsp_plot(rsp_signals, sampling_rate=None):
+def rsp_plot(rsp_signals, sampling_rate=None, figsize=(10, 10)):
     """**Visualize respiration (RSP) data**
 
     Parameters
@@ -13,6 +13,8 @@ def rsp_plot(rsp_signals, sampling_rate=None):
         DataFrame obtained from :func:`.rsp_process`.
     sampling_rate : int
         The desired sampling rate (in Hz, i.e., samples/second).
+    figsize : tuple
+        The size of the figure (width, height) in inches.
 
     See Also
     --------
@@ -42,7 +44,7 @@ def rsp_plot(rsp_signals, sampling_rate=None):
 
       # Plot
       @savefig p_rsp_plot1.png scale=100%
-      fig = nk.rsp_plot(rsp_signals)
+      nk.rsp_plot(rsp_signals, sampling_rate=1000)
       @suppress
       plt.close()
 
@@ -53,10 +55,15 @@ def rsp_plot(rsp_signals, sampling_rate=None):
     inhale = np.where(rsp_signals["RSP_Phase"] == 1)[0]
     exhale = np.where(rsp_signals["RSP_Phase"] == 0)[0]
 
+    nrow = 2
     if "RSP_Amplitude" in list(rsp_signals.columns):
-        fig, (ax0, ax1, ax2) = plt.subplots(nrows=3, ncols=1, sharex=True)
-    else:
-        fig, (ax0, ax1) = plt.subplots(nrows=2, ncols=1, sharex=True)
+        nrow += 1
+    if "RSP_RVT" in list(rsp_signals.columns):
+        nrow += 1
+    if "RSP_Symmetry_PeakTrough" in list(rsp_signals.columns):
+        nrow += 1
+
+    fig, ax = plt.subplots(nrows=nrow, ncols=1, sharex=True, figsize=figsize)
 
     # Determine unit of x-axis.
     last_ax = fig.get_axes()[-1]
@@ -67,25 +74,23 @@ def rsp_plot(rsp_signals, sampling_rate=None):
         last_ax.set_xlabel("Samples")
         x_axis = np.arange(0, len(rsp_signals))
 
-    plt.subplots_adjust(hspace=0.2)
-
     # Plot cleaned and raw respiration as well as peaks and troughs.
-    ax0.set_title("Raw and Cleaned Signal")
+    ax[0].set_title("Raw and Cleaned Signal")
     fig.suptitle("Respiration (RSP)", fontweight="bold")
 
-    ax0.plot(x_axis, rsp_signals["RSP_Raw"], color="#B0BEC5", label="Raw", zorder=1)
-    ax0.plot(
+    ax[0].plot(x_axis, rsp_signals["RSP_Raw"], color="#B0BEC5", label="Raw", zorder=1)
+    ax[0].plot(
         x_axis, rsp_signals["RSP_Clean"], color="#2196F3", label="Cleaned", zorder=2, linewidth=1.5
     )
 
-    ax0.scatter(
+    ax[0].scatter(
         x_axis[peaks],
         rsp_signals["RSP_Clean"][peaks],
         color="red",
         label="Exhalation Onsets",
         zorder=3,
     )
-    ax0.scatter(
+    ax[0].scatter(
         x_axis[troughs],
         rsp_signals["RSP_Clean"][troughs],
         color="orange",
@@ -96,7 +101,7 @@ def rsp_plot(rsp_signals, sampling_rate=None):
     # Shade region to mark inspiration and expiration.
     exhale_signal, inhale_signal = _rsp_plot_phase(rsp_signals, troughs, peaks)
 
-    ax0.fill_between(
+    ax[0].fill_between(
         x_axis[exhale],
         exhale_signal[exhale],
         rsp_signals["RSP_Clean"][exhale],
@@ -105,7 +110,7 @@ def rsp_plot(rsp_signals, sampling_rate=None):
         linestyle="None",
         label="exhalation",
     )
-    ax0.fill_between(
+    ax[0].fill_between(
         x_axis[inhale],
         inhale_signal[inhale],
         rsp_signals["RSP_Clean"][inhale],
@@ -115,24 +120,51 @@ def rsp_plot(rsp_signals, sampling_rate=None):
         label="inhalation",
     )
 
-    ax0.legend(loc="upper right")
+    ax[0].legend(loc="upper right")
 
     # Plot rate and optionally amplitude.
-    ax1.set_title("Breathing Rate")
-    ax1.plot(x_axis, rsp_signals["RSP_Rate"], color="#4CAF50", label="Rate", linewidth=1.5)
+    ax[1].set_title("Breathing Rate")
+    ax[1].plot(x_axis, rsp_signals["RSP_Rate"], color="#4CAF50", label="Rate", linewidth=1.5)
     rate_mean = np.mean(rsp_signals["RSP_Rate"])
-    ax1.axhline(y=rate_mean, label="Mean", linestyle="--", color="#4CAF50")
-    ax1.legend(loc="upper right")
+    ax[1].axhline(y=rate_mean, label="Mean", linestyle="--", color="#4CAF50")
+    ax[1].legend(loc="upper right")
 
     if "RSP_Amplitude" in list(rsp_signals.columns):
-        ax2.set_title("Breathing Amplitude")
+        ax[2].set_title("Breathing Amplitude")
 
-        ax2.plot(
+        ax[2].plot(
             x_axis, rsp_signals["RSP_Amplitude"], color="#009688", label="Amplitude", linewidth=1.5
         )
         amplitude_mean = np.mean(rsp_signals["RSP_Amplitude"])
-        ax2.axhline(y=amplitude_mean, label="Mean", linestyle="--", color="#009688")
-        ax2.legend(loc="upper right")
+        ax[2].axhline(y=amplitude_mean, label="Mean", linestyle="--", color="#009688")
+        ax[2].legend(loc="upper right")
+
+    if "RSP_RVT" in list(rsp_signals.columns):
+        ax[3].set_title("Respiratory Volume per Time")
+
+        ax[3].plot(x_axis, rsp_signals["RSP_RVT"], color="#00BCD4", label="RVT", linewidth=1.5)
+        rvt_mean = np.mean(rsp_signals["RSP_RVT"])
+        ax[3].axhline(y=rvt_mean, label="Mean", linestyle="--", color="#009688")
+        ax[3].legend(loc="upper right")
+
+    if "RSP_Symmetry_PeakTrough" in list(rsp_signals.columns):
+        ax[4].set_title("Cycle Symmetry")
+
+        ax[4].plot(
+            x_axis,
+            rsp_signals["RSP_Symmetry_PeakTrough"],
+            color="green",
+            label="Peak-Trough Symmetry",
+            linewidth=1.5,
+        )
+        ax[4].plot(
+            x_axis,
+            rsp_signals["RSP_Symmetry_RiseDecay"],
+            color="purple",
+            label="Rise-Decay Symmetry",
+            linewidth=1.5,
+        )
+        ax[4].legend(loc="upper right")
 
 
 # =============================================================================
