@@ -151,24 +151,22 @@ def signal_filter(
 
         # Sanity checks
         if lowcut is None and highcut is None:
-            raise ValueError(
-                "NeuroKit error: signal_filter(): you need to specify a 'lowcut' or a 'highcut'."
-            )
+            raise ValueError("NeuroKit error: signal_filter(): you need to specify a 'lowcut' or a 'highcut'.")
 
         if method in ["butter", "butterworth"]:
             filtered = _signal_filter_butterworth(signal, sampling_rate, lowcut, highcut, order)
         elif method in ["butter_ba", "butterworth_ba"]:
             filtered = _signal_filter_butterworth_ba(signal, sampling_rate, lowcut, highcut, order)
+        elif method in ["butter_zi", "butterworth_zi"]:
+            filtered = _signal_filter_butterworth_zi(signal, sampling_rate, lowcut, highcut, order)
         elif method in ["bessel"]:
             filtered = _signal_filter_bessel(signal, sampling_rate, lowcut, highcut, order)
         elif method in ["fir"]:
-            filtered = _signal_filter_fir(
-                signal, sampling_rate, lowcut, highcut, window_size=window_size
-            )
+            filtered = _signal_filter_fir(signal, sampling_rate, lowcut, highcut, window_size=window_size)
         else:
             raise ValueError(
                 "NeuroKit error: signal_filter(): 'method' should be",
-                " one of 'butterworth', 'butterworth_ba', 'bessel',",
+                " one of 'butterworth', 'butterworth_ba', 'butterworth_zi', 'bessel',",
                 " 'savgol' or 'fir'.",
             )
 
@@ -203,9 +201,7 @@ def _signal_filter_savgol(signal, sampling_rate=1000, order=2, window_size="defa
 # =============================================================================
 # FIR
 # =============================================================================
-def _signal_filter_fir(
-    signal, sampling_rate=1000, lowcut=None, highcut=None, window_size="default"
-):
+def _signal_filter_fir(signal, sampling_rate=1000, lowcut=None, highcut=None, window_size="default"):
     """Filter a signal using a FIR filter."""
     try:
         import mne
@@ -243,10 +239,7 @@ def _signal_filter_fir(
 
 def _signal_filter_butterworth(signal, sampling_rate=1000, lowcut=None, highcut=None, order=5):
     """Filter a signal using IIR Butterworth SOS method."""
-    freqs, filter_type = _signal_filter_sanitize(
-        lowcut=lowcut, highcut=highcut, sampling_rate=sampling_rate
-    )
-
+    freqs, filter_type = _signal_filter_sanitize(lowcut=lowcut, highcut=highcut, sampling_rate=sampling_rate)
     sos = scipy.signal.butter(order, freqs, btype=filter_type, output="sos", fs=sampling_rate)
     filtered = scipy.signal.sosfiltfilt(sos, signal)
     return filtered
@@ -255,9 +248,7 @@ def _signal_filter_butterworth(signal, sampling_rate=1000, lowcut=None, highcut=
 def _signal_filter_butterworth_ba(signal, sampling_rate=1000, lowcut=None, highcut=None, order=5):
     """Filter a signal using IIR Butterworth B/A method."""
     # Get coefficients
-    freqs, filter_type = _signal_filter_sanitize(
-        lowcut=lowcut, highcut=highcut, sampling_rate=sampling_rate
-    )
+    freqs, filter_type = _signal_filter_sanitize(lowcut=lowcut, highcut=highcut, sampling_rate=sampling_rate)
 
     b, a = scipy.signal.butter(order, freqs, btype=filter_type, output="ba", fs=sampling_rate)
     try:
@@ -268,15 +259,26 @@ def _signal_filter_butterworth_ba(signal, sampling_rate=1000, lowcut=None, highc
     return filtered
 
 
+def _signal_filter_butterworth_zi(signal, sampling_rate=1000, lowcut=None, highcut=None, order=5):
+    """Filter a signal using IIR Butterworth SOS method, given initial state (zi)."""
+
+    freqs, filter_type = _signal_filter_sanitize(lowcut=lowcut, highcut=highcut, sampling_rate=sampling_rate)
+
+    sos = scipy.signal.butter(order, freqs, btype=filter_type, output="sos", fs=sampling_rate)
+
+    zi_coeff = scipy.signal.sosfilt_zi(sos)
+    zi = zi_coeff * np.mean(signal)
+    # Filter data along one dimension using cascaded second-order sections.
+    return scipy.signal.sosfilt(sos, signal, zi=zi)[0]
+
+
 # =============================================================================
 # Bessel
 # =============================================================================
 
 
 def _signal_filter_bessel(signal, sampling_rate=1000, lowcut=None, highcut=None, order=5):
-    freqs, filter_type = _signal_filter_sanitize(
-        lowcut=lowcut, highcut=highcut, sampling_rate=sampling_rate
-    )
+    freqs, filter_type = _signal_filter_sanitize(lowcut=lowcut, highcut=highcut, sampling_rate=sampling_rate)
 
     sos = scipy.signal.bessel(order, freqs, btype=filter_type, output="sos", fs=sampling_rate)
     filtered = scipy.signal.sosfiltfilt(sos, signal)
@@ -307,8 +309,8 @@ def _signal_filter_powerline(signal, sampling_rate, powerline=50):
 def _signal_filter_sanitize(lowcut=None, highcut=None, sampling_rate=1000, normalize=False):
 
     # Sanity checks
-    if isinstance(highcut, int):
-        if sampling_rate <= 2 * highcut:
+    if lowcut is not None or highcut is not None:
+        if sampling_rate <= 2 * np.nanmax(np.array([lowcut, highcut], dtype=np.float64)):
             warn(
                 "The sampling rate is too low. Sampling rate"
                 " must exceed the Nyquist rate to avoid aliasing problem."
@@ -328,7 +330,8 @@ def _signal_filter_sanitize(lowcut=None, highcut=None, sampling_rate=1000, norma
             filter_type = "bandstop"
         else:
             filter_type = "bandpass"
-        freqs = [lowcut, highcut]
+        # pass frequencies in order of lowest to highest to the scipy filter
+        freqs = list(np.sort([lowcut, highcut]))
     elif lowcut is not None:
         freqs = [lowcut]
         filter_type = "highpass"
