@@ -29,6 +29,20 @@ def signal_plot(
     **kwargs : optional
         Arguments passed to matplotlib plotting.
 
+    See Also
+    --------
+    ecg_plot, rsp_plot, ppg_plot, emg_plot, eog_plot
+
+    Returns
+    -------
+    Though the function returns nothing, the figure can be retrieved and saved as follows:
+
+    .. code-block:: console
+
+        # To be run after signal_plot()
+        fig = plt.gcf()
+        fig.savefig("myfig.png")
+
     Examples
     ----------
     .. ipython:: python
@@ -45,9 +59,12 @@ def signal_plot(
 
     .. ipython:: python
 
+       # Simulate data
       data = pd.DataFrame({"Signal2": np.cos(np.linspace(start=0, stop=20, num=1000)),
                            "Signal3": np.sin(np.linspace(start=0, stop=20, num=1000)),
                            "Signal4": nk.signal_binarize(np.cos(np.linspace(start=0, stop=40, num=1000)))})
+
+      # Process signal
       @savefig p_signal_plot2.png scale=100%
       nk.signal_plot(data, labels=['signal_1', 'signal_2', 'signal_3'], subplots=True)
       nk.signal_plot([signal, data], standardize=True)
@@ -69,7 +86,13 @@ def signal_plot(
         if isinstance(signal, list) or len(np.array(signal).shape) > 1:
             out = pd.DataFrame()
             for i, content in enumerate(signal):
-                if isinstance(content, (pd.DataFrame, pd.Series)):
+                if isinstance(content, pd.Series):
+                    out = pd.concat(
+                        [out, pd.DataFrame({content.name: content.values})],
+                        axis=1,
+                        sort=True,
+                    )
+                elif isinstance(content, pd.DataFrame):
                     out = pd.concat([out, content], axis=1, sort=True)
                 else:
                     out = pd.concat(
